@@ -7,6 +7,7 @@ Make sure you're running a UDP server on port 9000 (see udp_server.py).
 
 There's nothing gevent-specific here.
 """
+from __future__ import print_function
 import sys
 from gevent import socket
 
@@ -14,7 +15,7 @@ address = ('localhost', 9000)
 message = ' '.join(sys.argv[1:])
 sock = socket.socket(type=socket.SOCK_DGRAM)
 sock.connect(address)
-print 'Sending %s bytes to %s:%s' % ((len(message), ) + address)
-sock.send(message)
+print('Sending %s bytes to %s:%s' % ((len(message), ) + address))
+sock.send(message.encode())
 data, address = sock.recvfrom(8192)
-print '%s:%s: got %r' % (address + (data, ))
+print('%s:%s: got %r' % (address + (data, )))
