@@ -16,11 +16,13 @@ import sys
 import re
 import traceback
 from cgi import escape
+
 try:
     import urllib2
     from urlparse import urlparse
     from urllib import unquote
 except ImportError:
+    # pylint:disable=import-error,no-name-in-module
     from urllib import request as urllib2
     from urllib.parse import urlparse
     from urllib.parse import unquote
@@ -65,6 +67,7 @@ def application(env, start_response):
 
 
 def proxy(path, start_response, proxy_url):
+    # pylint:disable=too-many-locals
     if '://' not in path:
         path = 'http://' + path
     try:
@@ -74,13 +77,14 @@ def proxy(path, start_response, proxy_url):
             response = ex
         print('%s: %s %s' % (path, response.code, response.msg))
         headers = [(k, v) for (k, v) in response.headers.items() if k not in drop_headers]
-        scheme, netloc, path, params, query, fragment = urlparse(path)
+        scheme, netloc, path, _params, _query, _fragment = urlparse(path)
         host = (scheme or 'http') + '://' + netloc
-    except Exception as ex:
+    except Exception as ex: # pylint:disable=broad-except
         sys.stderr.write('error while reading %s:\n' % path)
         traceback.print_exc()
         tb = traceback.format_exc()
         start_response('502 Bad Gateway', [('Content-Type', 'text/html')])
+        # pylint:disable=deprecated-method
         error_str = escape(str(ex) or ex.__class__.__name__ or 'Error')
         error_str = '<h1>%s</h1><h2>%s</h2><pre>%s</pre>' % (error_str, escape(path), escape(tb))
         return [_as_bytes(error_str)]
@@ -100,12 +104,11 @@ def join(url1, *rest):
     if url1.endswith(b'/'):
         if url2.startswith(b'/'):
             return join(url1 + url2[1:], *rest)
-        else:
-            return join(url1 + url2, *rest)
+        return join(url1 + url2, *rest)
     elif url2.startswith(b'/'):
         return join(url1 + url2, *rest)
-    else:
-        return join(url1 + b'/' + url2, *rest)
+
+    return join(url1 + b'/' + url2, *rest)
 
 
 def fix_links(data, proxy_url, host_url):
